github_kamangir = "https://github.com/kamangir"

algo_docs = f"{github_kamangir}/bluer-algo/blob/main/bluer_algo/docs"

assets = f"{github_kamangir}/assets/raw/main"

assets2 = f"{github_kamangir}/assets2/raw/main"

assets2_bluer_eagle = f"{assets2}/bluer-eagle"
assets2_bluer_fire = f"{assets2}/bluer-fire"
assets2_bluer_robin = f"{assets2}/bluer-robin"
assets2_bluer_swallow = f"{assets2}/bluer-swallow"
assets2_bluer_sparrow = f"{assets2}/bluer-sparrow"

bluer_ugv_mechanical_design = f"{github_kamangir}/bluer-ugv-mechanical-design/"
bluer_sparrow_mechanical_design = (
    f"{bluer_ugv_mechanical_design}/blob/main/bluer_sparrow"
)
bluer_swallow_mechanical_design = (
    f"{bluer_ugv_mechanical_design}/blob/main/bluer_swallow"
)



from bluer_objects.README.items import ImageItems

items = [
    {
        "path": "../docs/bluer_swallow/analog",
        "items": ImageItems(
            {
                "../../../../diagrams/bluer_swallow/analog.png": "../../../../diagrams/bluer_swallow/analog.svg",
            }
        ),
    }
]
